/*!
 * touchNav, a jQuery plugin for handling drop down navs on touch devices.
 * Author: iwong
 * Licensed under the MIT license
 */

(function ($, window, document) {

  // Create the defaults once
  var pluginName = 'touchNav';
  var defaults = {};

  // The actual plugin constructor
  function Plugin (element, options) {
    this.element = element;
    this.options = $.extend({}, defaults, options);
    this.defaults = defaults;
    this.name = pluginName;
    this.init();
  }

  function resetLastTouched (el) {
    $(el).children().find('a').data('first-touch', false);
    $(el).find('li').removeClass('nav-hover');
  }

  function registerMenuItems (el, options, level) {
    // Tap once on menu items without nested nav to open link
    // Tap once on menu items with nested nav will open menu
    // Tap twice on menu items with nested nav to open link
    $(el).children().find(level).on('touchend', function (e) {
      var $el = $(this);
      var link = $el.attr('href');

      if ($el.parent().find('ul').length <= 0 || $el.data('first-touch')) {
        // no children
        window.location.href = link;
      } else {
        // has children show drop down
        resetLastTouched(el);
        $el.data('first-touch', true);

        // android chrome fix
        $el.parents().addClass('nav-hover');
        return false;
      }
    });
  }

  function tapOutHideOpenMenus (el, options) {
    // Tap anywhere outside to close menus
    $('body').on('click touchend', function (e) {
      if (!$.contains(el, e.target)) {
        resetLastTouched(el);
        $(el).children().trigger('mouseleave');
      }
    });
  }

  Plugin.prototype = {
    init: function() {
      registerMenuItems(this.element, this.options, '> a');
      registerMenuItems(this.element, this.options, '> ul > li > a');
      tapOutHideOpenMenus(this.element, this.options);
    }
  };

  // A really lightweight plugin wrapper around the constructor,
  // preventing against multiple instantiations
  $.fn[pluginName] = function (options) {
    return this.each(function () {
      if (!$.data(this, 'plugin_' + pluginName)) {
        $.data(this, 'plugin_' + pluginName,
          new Plugin(this, options));
      }
    });
  };

})(jQuery, window, document);
